@@ -1,4 +1,3 @@
-
 setClassUnion("optionalDataFrame", c("data.frame","NULL"))
 
 
@@ -10,9 +9,11 @@ setClassUnion("optionalNumeric", c("numeric","NULL"))
 
 setClassUnion("optionalCharacter", c("character","NULL"))
 
+setClassUnion("optionalList", c("list","NULL"))
+
 # Compute standard error of an object.
 setGeneric("SE",
-    def = function(obj) {
+    def = function(obj, ...) {
       standardGeneric("SE")
     })
 
@@ -53,4 +54,4 @@ setGeneric("hessian",	function(object) standardGeneric("hessian"))
 # TODO: make poisson abundance child class
 # TODO: make show method for each of these classes.
 # TODO: make unmarkedFit show that calls the respective children.
-# TODO: separate unmarkedFit class for each model type?... would contain different estimate types
\ No newline at end of file
+# TODO: separate unmarkedFit class for each model type?... would contain different estimate types
